==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/workflows/PushOptions.java <==
package io.github.cdklabs.projen.github.workflows;

/**
 * (experimental) Options for push-like events.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.791Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.workflows.PushOptions")
@software.amazon.jsii.Jsii.Proxy(PushOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface PushOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) When using the push and pull_request events, you can configure a workflow to run on specific branches or tags.
     * <p>
     * For a pull_request event, only
     * branches and tags on the base are evaluated. If you define only tags or
     * only branches, the workflow won't run for events affecting the undefined
     * Git ref.
     * <p>
     * @see https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getBranches() {
        return null;
    }

    /**
     * (experimental) When using the push and pull_request events, you can configure a workflow to run when at least one file does not match paths-ignore or at least one modified file matches the configured paths.
     * <p>
     * Path filters are not
     * evaluated for pushes to tags.
     * <p>
     * @see https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getPaths() {
        return null;
    }

    /**
     * (experimental) When using the push and pull_request events, you can configure a workflow to run on specific branches or tags.
     * <p>
     * For a pull_request event, only
     * branches and tags on the base are evaluated. If you define only tags or
     * only branches, the workflow won't run for events affecting the undefined
     * Git ref.
     * <p>
     * @see https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link PushOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PushOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<PushOptions> {
        java.util.List<java.lang.String> branches;
        java.util.List<java.lang.String> paths;
        java.util.List<java.lang.String> tags;

        /**
         * Sets the value of {@link PushOptions#getBranches}
         * @param branches When using the push and pull_request events, you can configure a workflow to run on specific branches or tags.
         *                 For a pull_request event, only
         *                 branches and tags on the base are evaluated. If you define only tags or
         *                 only branches, the workflow won't run for events affecting the undefined
         *                 Git ref.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder branches(java.util.List<java.lang.String> branches) {
            this.branches = branches;
            return this;
        }

        /**
         * Sets the value of {@link PushOptions#getPaths}
         * @param paths When using the push and pull_request events, you can configure a workflow to run when at least one file does not match paths-ignore or at least one modified file matches the configured paths.
         *              Path filters are not
         *              evaluated for pushes to tags.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder paths(java.util.List<java.lang.String> paths) {
            this.paths = paths;
            return this;
        }

        /**
         * Sets the value of {@link PushOptions#getTags}
         * @param tags When using the push and pull_request events, you can configure a workflow to run on specific branches or tags.
         *             For a pull_request event, only
         *             branches and tags on the base are evaluated. If you define only tags or
         *             only branches, the workflow won't run for events affecting the undefined
         *             Git ref.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tags(java.util.List<java.lang.String> tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PushOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public PushOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link PushOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PushOptions {
        private final java.util.List<java.lang.String> branches;
        private final java.util.List<java.lang.String> paths;
        private final java.util.List<java.lang.String> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.branches = software.amazon.jsii.Kernel.get(this, "branches", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.paths = software.amazon.jsii.Kernel.get(this, "paths", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.branches = builder.branches;
            this.paths = builder.paths;
            this.tags = builder.tags;
        }

        @Override
        public final java.util.List<java.lang.String> getBranches() {
            return this.branches;
        }

        @Override
        public final java.util.List<java.lang.String> getPaths() {
            return this.paths;
        }

        @Override
        public final java.util.List<java.lang.String> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBranches() != null) {
                data.set("branches", om.valueToTree(this.getBranches()));
            }
            if (this.getPaths() != null) {
                data.set("paths", om.valueToTree(this.getPaths()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.workflows.PushOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PushOptions.Jsii$Proxy that = (PushOptions.Jsii$Proxy) o;

            if (this.branches != null ? !this.branches.equals(that.branches) : that.branches != null) return false;
            if (this.paths != null ? !this.paths.equals(that.paths) : that.paths != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.branches != null ? this.branches.hashCode() : 0;
            result = 31 * result + (this.paths != null ? this.paths.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/workflows/PushOptions.java <==
package io.github.cdklabs.projen.github.workflows;

/**
 * (experimental) Options for push-like events.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.459Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.workflows.PushOptions")
@software.amazon.jsii.Jsii.Proxy(PushOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface PushOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) When using the push, pull_request and pull_request_target events, you can configure a workflow to run on specific branches or tags.
     * <p>
     * For a pull_request event, only
     * branches and tags on the base are evaluated. If you define only tags or
     * only branches, the workflow won't run for events affecting the undefined
     * Git ref.
     * <p>
     * @see <a href="https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet">https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getBranches() {
        return null;
    }

    /**
     * (experimental) When using the push, pull_request and pull_request_target events, you can configure a workflow to run when at least one file does not match paths-ignore or at least one modified file matches the configured paths.
     * <p>
     * Path filters are not
     * evaluated for pushes to tags.
     * <p>
     * @see <a href="https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet">https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getPaths() {
        return null;
    }

    /**
     * (experimental) When using the push, pull_request and pull_request_target events, you can configure a workflow to run on specific branches or tags.
     * <p>
     * For a pull_request event, only
     * branches and tags on the base are evaluated. If you define only tags or
     * only branches, the workflow won't run for events affecting the undefined
     * Git ref.
     * <p>
     * @see <a href="https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet">https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link PushOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PushOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<PushOptions> {
        java.util.List<java.lang.String> branches;
        java.util.List<java.lang.String> paths;
        java.util.List<java.lang.String> tags;

        /**
         * Sets the value of {@link PushOptions#getBranches}
         * @param branches When using the push, pull_request and pull_request_target events, you can configure a workflow to run on specific branches or tags.
         *                 For a pull_request event, only
         *                 branches and tags on the base are evaluated. If you define only tags or
         *                 only branches, the workflow won't run for events affecting the undefined
         *                 Git ref.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder branches(java.util.List<java.lang.String> branches) {
            this.branches = branches;
            return this;
        }

        /**
         * Sets the value of {@link PushOptions#getPaths}
         * @param paths When using the push, pull_request and pull_request_target events, you can configure a workflow to run when at least one file does not match paths-ignore or at least one modified file matches the configured paths.
         *              Path filters are not
         *              evaluated for pushes to tags.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder paths(java.util.List<java.lang.String> paths) {
            this.paths = paths;
            return this;
        }

        /**
         * Sets the value of {@link PushOptions#getTags}
         * @param tags When using the push, pull_request and pull_request_target events, you can configure a workflow to run on specific branches or tags.
         *             For a pull_request event, only
         *             branches and tags on the base are evaluated. If you define only tags or
         *             only branches, the workflow won't run for events affecting the undefined
         *             Git ref.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tags(java.util.List<java.lang.String> tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PushOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public PushOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link PushOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PushOptions {
        private final java.util.List<java.lang.String> branches;
        private final java.util.List<java.lang.String> paths;
        private final java.util.List<java.lang.String> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.branches = software.amazon.jsii.Kernel.get(this, "branches", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.paths = software.amazon.jsii.Kernel.get(this, "paths", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.branches = builder.branches;
            this.paths = builder.paths;
            this.tags = builder.tags;
        }

        @Override
        public final java.util.List<java.lang.String> getBranches() {
            return this.branches;
        }

        @Override
        public final java.util.List<java.lang.String> getPaths() {
            return this.paths;
        }

        @Override
        public final java.util.List<java.lang.String> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBranches() != null) {
                data.set("branches", om.valueToTree(this.getBranches()));
            }
            if (this.getPaths() != null) {
                data.set("paths", om.valueToTree(this.getPaths()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.workflows.PushOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PushOptions.Jsii$Proxy that = (PushOptions.Jsii$Proxy) o;

            if (this.branches != null ? !this.branches.equals(that.branches) : that.branches != null) return false;
            if (this.paths != null ? !this.paths.equals(that.paths) : that.paths != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.branches != null ? this.branches.hashCode() : 0;
            result = 31 * result + (this.paths != null ? this.paths.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
